@@ -187,6 +187,17 @@ void BNPView::lateInit()
 	m_hideTimer    = new QTimer(this);
 	connect( m_tryHideTimer, SIGNAL(timeout()), this, SLOT(timeoutTryHide()) );
 	connect( m_hideTimer,    SIGNAL(timeout()), this, SLOT(timeoutHide())    );
+
+	// Preload every baskets for instant filtering:
+/*StopWatch::start(100);
+	QListViewItemIterator it(m_tree);
+	while (it.current()) {
+		BasketListViewItem *item = ((BasketListViewItem*)it.current());
+		item->basket()->load();
+		kapp->processEvents();
+		++it;
+	}
+StopWatch::check(100);*/
 }
 
 void BNPView::addWelcomeBaskets()
@@ -1111,6 +1122,9 @@ void BNPView::setCurrentBasket(Basket *basket)
 	if (currentBasket())
 		currentBasket()->closeBasket();
 
+	if (basket)
+		basket->aboutToBeActivated();
+
 	BasketListViewItem *item = listViewItemForBasket(basket);
 	if (item) {
 		m_tree->setSelected(item, true);
@@ -1127,6 +1141,7 @@ void BNPView::setCurrentBasket(Basket *basket)
 		if (Global::systemTray)
 			Global::systemTray->updateToolTip();
 		m_tree->ensureItemVisible(m_tree->currentItem());
+		item->basket()->setFocus();
 	}
 	m_tree->viewport()->update();
 	emit basketChanged();
